@@ -1,5 +1,5 @@
 //! A circular buffer with fixed capacity.
-//! Requires Rust 1.12+
+//! Requires Rust 1.17+
 //!
 //! It can be stored directly on the stack if needed.
 //!
@@ -15,7 +15,6 @@
 //!
 //! - `std`
 //!   - Optional, enabled by default
-//!   - Requires Rust 1.6 *to disable*
 //!   - Use libstd
 //!
 //!
@@ -30,7 +29,7 @@
 //!   - Optional
 //!   - Requires Rust stable channel
 //!   - Depend on generic-array and allow using it just like a fixed
-//!     size array for ArrayVec storage.
+//!     size array for ArrayDeque storage.
 //!
 //!
 //! # Usage
@@ -39,7 +38,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! arraydeque = "0.1.3"
+//! arraydeque = "0.2"
 //! ```
 //!
 //! Next, add this to your crate root:
@@ -54,9 +53,16 @@
 //!
 //! ```toml
 //! [dependencies]
-//! arraydeque = { version = "0.1.3", default-features = false }
+//! arraydeque = { version = "0.2", default-features = false }
 //! ```
 //!
+//! # Capacity
+//!
+//! Note that the `capacity()` is always `backed_array.len() - 1`.
+//! [Read more]
+//!
+//! [Read more]: https://en.wikipedia.org/wiki/Circular_buffer
+//!
 //! # Examples
 //! ```
 //! extern crate arraydeque;
@@ -144,7 +150,7 @@
 //! generic-array = "0.5.1"
 //!
 //! [dependencies.arraydeque]
-//! version = "0.1.3"
+//! version = "0.2"
 //! features = ["use_generic_array"]
 //! ```
 //! ```
@@ -177,14 +183,16 @@
 //! # fn main() {}
 //! ```
 
-#![cfg_attr(not(feature="std"), no_std)]
+#![cfg_attr(not(any(feature="std", test)), no_std)]
+
 extern crate odds;
 extern crate nodrop;
 
 #[cfg(feature = "use_generic_array")]
 extern crate generic_array;
 
-#[cfg(not(feature="std"))]
+// #![cfg_attr(not(or(feature="std", test), no_std))]
+#[cfg(not(any(feature="std", test)))]
 extern crate core as std;
 
 use std::mem;
@@ -583,7 +591,7 @@ impl<A: Array> ArrayDeque<A> {
         }
     }
 
-    /// Return the capacity of the `ArrayVec`.
+    /// Return the capacity of the `ArrayDeque`.
     ///
     /// # Capacity
     ///
@@ -1874,6 +1882,7 @@ fn count(tail: usize, head: usize, capacity: usize) -> usize {
 }
 
 /// `ArrayDeque` iterator
+#[must_use = "iterator adaptors are lazy and do nothing unless consumed"]
 #[derive(Clone)]
 pub struct Iter<'a, T: 'a> {
     ring: &'a [T],
@@ -1915,6 +1924,7 @@ impl<'a, T> DoubleEndedIterator for Iter<'a, T> {
 impl<'a, T> ExactSizeIterator for Iter<'a, T> {}
 
 /// `ArrayDeque` mutable iterator
+#[must_use = "iterator adaptors are lazy and do nothing unless consumed"]
 pub struct IterMut<'a, T: 'a> {
     ring: &'a mut [T],
     head: usize,
@@ -1963,6 +1973,7 @@ impl<'a, T> DoubleEndedIterator for IterMut<'a, T> {
 impl<'a, T> ExactSizeIterator for IterMut<'a, T> {}
 
 /// A by-value `ArrayDeque` iterator
+#[must_use = "iterator adaptors are lazy and do nothing unless consumed"]
 pub struct IntoIter<A: Array> {
     inner: ArrayDeque<A>,
 }
